# HangMan
[![Downloads](https://pepy.tech/badge/hangman-ultimate)](https://pepy.tech/project/hangman-ultimate)
[![Downloads](https://pepy.tech/badge/hangman-ultimate/month)](https://pepy.tech/project/hangman-ultimate/month)
[![Downloads](https://pepy.tech/badge/hangman-ultimate/week)](https://pepy.tech/project/hangman-ultimate/week)

A character user interface of the  popular game hangman 
![HANGMAN OPENING](https://raw.githubusercontent.com/devarshi16/HangMan/master/hangman_terminal.png)
```
pip install hangman-ultimate
```
This repository provides code for my [blog](https://attackonalgorithms.wordpress.com/2019/10/24/slightly-non-trivial-implementation-of-cli-hangman-a-hands-on-python-tutorial/) 

